==> 4.0.0-ISS-GKLM-FP0005-AIX.tar.gz: _uninst/rollback.sh <==
#!/bin/sh
#set -x
# Licensed Materials-Property of IBM
# (C)Copyright IBM Corp 2008
# All rights reserved
# US Government Users Restricted Rights
# Use, duplication, or disclosure restricted
# by GSA ADP Schedule Contract with IBM Corp
# 
# The script is to be called from the IBM Security Key Life Cycle Manager 
# Installer
# arg1 -  dbinstance_owner_home - (For example /home/db2inst2)
# arg2 -  instance  -  instance name (for example db2inst2) 
# arg3 -  dbport - - database port 
#
#------------------------------------------------------------------------------

WAS_HOME=$1
appDataLocation=$2
WAS_ADMIN_ID=$3
WAS_ADMIN_PASSWORD=$4
installlocation=$5
TMPDIR=$6

$WAS_HOME/bin/wsadmin.sh  -lang jython -conntype NONE -profileName KLMProfile -tracefile $appDataLocation/logs/sklmLogs/wsadmin.log -appendtrace true -username $WAS_ADMIN_ID -password $WAS_ADMIN_PASSWORD -c "print AdminApp.uninstall('sklm_kms')"; 
#undeploy 

#save
$WAS_HOME/bin/wsadmin.sh  -lang jython -conntype NONE -profileName KLMProfile -tracefile $appDataLocation/logs/sklmLogs/wsadmin.log -appendtrace true -username $WAS_ADMIN_ID -password $WAS_ADMIN_PASSWORD -c "print AdminConfig.save()";

rm -rf $WAS_HOME/plugins/com.ibm.tklm.commands.jar
rm -rf $WAS_HOME/installableApps/com.ibm.tklm.ear
rm -rf $installlocation/1986-03.com.ibm_ibm.com_IBM_Security_Key_Lifecycle_Manager_-_Runtime_Server-4.0.0.swidtag
#osghi refresh 

cp $TMPDIR/plugins/com.ibm.tklm.commands.jar $WAS_HOME/plugins
cp $TMPDIR/was/com.ibm.tklm.ear $WAS_HOME/installableApps
							 
		
$WAS_HOME/bin/wsadmin.sh -lang jacl -conntype NONE -profileName KLMProfile -tracefile $appDataLocation/logs/sklmLogs/wsadmin.log -appendtrace true -username $WAS_ADMIN_ID -password $WAS_ADMIN_PASSWORD -c '$AdminApp install '$WAS_HOME/installableApps/com.ibm.tklm.ear' {-node SKLMNode -server server1 -appname sklm_kms -usedefaultbindings -deployws -MapWebModToVH {{.* .* default_host}}}';
		
					
$WAS_HOME/bin/wsadmin.sh  -lang jython -conntype NONE -profileName KLMProfile -tracefile $appDataLocation/logs/sklmLogs/wsadmin.log -appendtrace true -username $WAS_ADMIN_ID -password $WAS_ADMIN_PASSWORD -c "print AdminConfig.save()";



$WAS_HOME/bin/stopServer.sh server1 -username $WAS_ADMIN_ID -password $WAS_ADMIN_PASSWORD
$WAS_HOME/bin/startServer.sh server1

==> 4.1.0-ISS-GKLM-FP0005-AIX.tar.gz: _uninst/rollback.sh <==
#!/bin/sh
#set -x
# Licensed Materials-Property of IBM
# (C)Copyright IBM Corp 2008
# All rights reserved
# US Government Users Restricted Rights
# Use, duplication, or disclosure restricted
# by GSA ADP Schedule Contract with IBM Corp
# 
# The script is to be called from the IBM Security Guardium Key Life Cycle Manager 
# Installer
# arg1 -  dbinstance_owner_home - (For example /home/db2inst2)
# arg2 -  instance  -  instance name (for example db2inst2) 
# arg3 -  dbport - - database port 
#
#------------------------------------------------------------------------------

WAS_HOME=$1
appDataLocation=$2
WAS_ADMIN_ID=$3
WAS_ADMIN_PASSWORD=$4
installlocation=$5
TMPDIR=$6

$WAS_HOME/bin/wsadmin.sh  -lang jython -conntype NONE -profileName KLMProfile -tracefile $appDataLocation/logs/sklmLogs/wsadmin.log -appendtrace true -username $WAS_ADMIN_ID -password $WAS_ADMIN_PASSWORD -c "print AdminApp.uninstall('sklm_kms')"; 
#undeploy 

#save
$WAS_HOME/bin/wsadmin.sh  -lang jython -conntype NONE -profileName KLMProfile -tracefile $appDataLocation/logs/sklmLogs/wsadmin.log -appendtrace true -username $WAS_ADMIN_ID -password $WAS_ADMIN_PASSWORD -c "print AdminConfig.save()";

rm -rf $WAS_HOME/plugins/com.ibm.tklm.commands.jar
rm -rf $WAS_HOME/installableApps/com.ibm.tklm.ear
rm -rf $installlocation/1986-03.com.ibm_ibm.com_IBM_Security_Key_Lifecycle_Manager_-_Runtime_Server-4.1.0.swidtag
#osghi refresh 

cp $TMPDIR/plugins/com.ibm.tklm.commands.jar $WAS_HOME/plugins
cp $TMPDIR/was/com.ibm.tklm.ear $WAS_HOME/installableApps
							 
		
$WAS_HOME/bin/wsadmin.sh -lang jacl -conntype NONE -profileName KLMProfile -tracefile $appDataLocation/logs/sklmLogs/wsadmin.log -appendtrace true -username $WAS_ADMIN_ID -password $WAS_ADMIN_PASSWORD -c '$AdminApp install '$WAS_HOME/installableApps/com.ibm.tklm.ear' {-node SKLMNode -server server1 -appname sklm_kms -usedefaultbindings -deployws -MapWebModToVH {{.* .* default_host}}}';
		
					
$WAS_HOME/bin/wsadmin.sh  -lang jython -conntype NONE -profileName KLMProfile -tracefile $appDataLocation/logs/sklmLogs/wsadmin.log -appendtrace true -username $WAS_ADMIN_ID -password $WAS_ADMIN_PASSWORD -c "print AdminConfig.save()";



$WAS_HOME/bin/stopServer.sh server1 -username $WAS_ADMIN_ID -password $WAS_ADMIN_PASSWORD
$WAS_HOME/bin/startServer.sh server1
